#! /bin/csh -f

#  T. Jarrett  (June 4, 2008)
#  this script runs the automated saturated star rectification for IRAC/MIPS

set image = $1
set intable = $2     # optional -- input table (ra dec) of sources to process
set verbose = $3     # optional ;  example:  -v  to set verbose

#  program binary
set binary = ./BCDimageworks

# path to PSFs and ancillary IRAC images
set ppth = /Users/jarrett/science/irac/psfs/new/  #  path to where the PSF images live
#set cpth = /Users/jarrett/science/irac/photcorr/ #   path to where the correction images live
set cpth = null

# input 2MASS stars needed to find saturated stars
set stars = stars.tbl  # 2MASS stars table name


#############################################
# the following are IRAC-specific parameters
set Rphot_1 = 12.0  # standard IRAC photometry aperture (arcsec)
set Rinner_1 = 14.4 # inner radius of annulus (asec)
set awidth_1 = 10.0  # width of annulus (arcsec)

# the following are MIPS-specific parameters
set Rphot_2 = 13.0  # standard IRAC photometry aperture (arcsec)
set Rinner_2 = 20.0 # inner radius of annulus (asec)
set awidth_2 = 12.0  # width of annulus (arcsec)

# the following are tool-specific parameters, which should generally not be changed

set Rextract = 50.0  # extraction radius
set SNRlim = 3.0  # S/N limit for constructing the SB profile
set Area_Thresh = 0.50  # threshold for radial SB pixels vs. annular area
set Fzone = 1.25  # radius scaling factor to replace saturated pixels with model (def=1.3)
set Pratio_thresh = 0.80  # peak ratio threshold between star-to-PSF  (default = 0.80)
set Fratio_thresh = 0.80  # int. flux ratio threshold between star-to-PSF  (default = 0.80)
set RMS_thresh = 0.333    # residual RMS, used as a goodness of fit metric  (default = 0.333)

#  2MASS table parameters
set Klim = 13.5  # for source subtraction assuming 1.2s exposures
set Krater = 9.0  # for crater finding (def = 8.5), assuming 1.2s exposures
set JKcolor = 1.0  # nominal color of stars threshold; redder stars get a brighter Klim,Krater

# IRAC PSF file names

set gfactor_irac = 5.   # this is the resampling factor; for IRAC, 5x to the original pixel scale

set PSF1 = 'IRAC.1.HDRPRF5X_puffed.fits'
set PSF2 = 'IRAC.2.HDRPRF5X_puffed.fits'
set PSF3 = 'IRAC.3.HDRPRF5X_puffed.fits'
set PSF4 = 'IRAC.4.HDRPRF5X_puffed.fits'

# MIPS-24 PSF

set gfactor_mips = 10.
#set PSF24 = 'mips24_10000K_box18.fits'
set PSF24 = 'mips24_10000K_box18_puffed.fits'

#set gfactor_mips = 4.0   # this is the resampling factor; for MIPS, 10x to the original pixel scale
#set  PSF24 = 'mips_24_5000c.fits'
#set  PSF24 = 'temp.fits'


#####################################################################################################

set intab = 'null'
set vmode = 'null'

if ($intable == '') then
	set intab = 'null'
else if ($intable == '-v') then
	set verbose = '-v'
else if (-e $intable) then
	set intab = $intable
endif

if ($verbose == '-v') set vmode = '-v'
	

set inf = imageworks.inp
if (-e $inf) rm $inf

echo $image > $inf
echo $intab >> $inf
echo $vmode >> $inf
echo $Rphot_1 >> $inf
echo $Rinner_1 >> $inf
echo $awidth_1 >> $inf

echo $Rphot_2 >> $inf
echo $Rinner_2 >> $inf
echo $awidth_2 >> $inf

echo $Rextract >> $inf 
echo $SNRlim  >> $inf
echo $Area_Thresh  >> $inf
echo $Fzone  >> $inf
echo $Pratio_thresh  >> $inf
echo $Fratio_thresh  >> $inf

echo $stars  >> $inf
echo $Klim  >> $inf
echo $Krater  >> $inf
echo $JKcolor  >> $inf

echo $ppth  >> $inf
echo $cpth  >> $inf

echo $gfactor_irac >> $inf
echo $PSF1 >> $inf
echo $PSF2 >> $inf
echo $PSF3 >> $inf
echo $PSF4 >> $inf

echo $gfactor_mips >> $inf
echo $PSF24 >> $inf

echo $RMS_thresh >> $inf

$binary $inf


